@@ -9,7 +9,7 @@ use Carp qw( croak carp );
 use POSIX ":sys_wait_h";
 use IO::Pipe;
 
-our $VERSION = '1.05'; # VERSION
+our $VERSION = '1.06'; # VERSION
 
 sub new {
     my $class = shift;
@@ -40,7 +40,7 @@ sub new {
         my $user = getlogin || getpwuid($<) || 'root';
         $self->{_daemon}{user} ||= $user;
     }
-    $self->{_daemon}{group} ||= $self->{_daemon}{user};
+    $self->{_daemon}{group} ||= ( getgrgid( (getpwnam( $self->{_daemon}{user} ) )[3] ) )[0];
 
     croak 'new() called without "daemon" parameter as a hashref' unless ( ref( $self->{_daemon} ) eq 'HASH' );
     for ( qw( program program_args ) ) {
@@ -317,7 +317,7 @@ Daemon::Device - Forking daemon device construct
 
 =head1 VERSION
 
-version 1.05
+version 1.06
 
 =for markdown [![Build Status](https://travis-ci.org/gryphonshafer/Daemon-Device.svg)](https://travis-ci.org/gryphonshafer/Daemon-Device)
 [![Coverage Status](https://coveralls.io/repos/gryphonshafer/Daemon-Device/badge.png)](https://coveralls.io/r/gryphonshafer/Daemon-Device)
